@@ -10,8 +10,6 @@ USER_NAME = "Overridden user Name"
 USER_EMAIL = "hello@nowhere.com"
 DEFAULT_BRANCH = "any_branch"
 
-pytestmark = pytest.mark.mypy_testing
-
 
 @pytest.fixture
 def git_user_name() -> str:
@@ -28,7 +26,12 @@ def git_init_default_branch() -> str:
     return DEFAULT_BRANCH
 
 
-def test_gitconfig_fixture_override_defaults(
+@pytest.fixture
+def set_gitconfig() -> dict[str, str]:
+    return {"some.settings": "100", "other.settings": "200"}
+
+
+def test_function_fixtures_dont_override_ession_scoped_defaults(
     default_gitconfig: GitConfig,
     default_git_user_name: str,
     default_git_user_email: str,
@@ -37,11 +40,17 @@ def test_gitconfig_fixture_override_defaults(
     assert default_gitconfig.get("user.name") == default_git_user_name
     assert default_gitconfig.get("user.email") == default_git_user_email
     assert default_gitconfig.get("init.defaultBranch") == default_git_init_default_branch
+    assert default_gitconfig.get("some.settings") == "42"
     assert "GIT_WHATEVER" not in os.environ
 
+    with pytest.raises(KeyError):
+        default_gitconfig.get("other.setting")
+
 
 def test_gitconfig_fixture_override(gitconfig: GitConfig):
     assert gitconfig.get("user.name") == USER_NAME
     assert gitconfig.get("user.email") == USER_EMAIL
     assert gitconfig.get("init.defaultBranch") == DEFAULT_BRANCH
+    assert gitconfig.get("some.settings") == "100"
+    assert gitconfig.get("other.settings") == "200"
     assert "GIT_WHATEVER" not in os.environ
